pub enum InternalEntry {
Erase {
page: Nat,
},
Clear {
min_key: Nat,
},
Marker {
count: Nat,
},
Remove {
key: Nat,
},
}Expand description
Internal entry.
Variants
Erase
Indicates that a page should be erased.
Clear
Indicates that user entries with high key should be deleted.
Marker
Marks the start of a transaction.
The marker is followed by a given number of updates, which are either user entries or remove entries.
Remove
Indicates that a user entry should be removed.
This is only useful (and valid) as part of a transaction, since removing a single entry is already atomic.