pub struct InitInfo {
pub cycle: Nat,
pub prefix: Nat,
}Expand description
Information for an initialized page.
Fields
cycle: NatThe number of times this page has been erased.
prefix: NatThe word index of the first entry in this virtual page.