Position

Struct Position 

pub struct Position(/* private fields */);
The position of a word in the virtual storage.

With the notations defined in Format, let:

  • w denote a word offset in a virtual page, thus between 0 and Q - 1
  • p denote a page offset, thus between 0 and N - 1
  • c denote the number of times a page was erased, thus between 0 and E

The position of a word is (c * N + p) * Q + w. This position monotonically increases and represents the consumed lifetime of the storage.

This type is kept abstract to avoid possible confusion with Nat and Word if they happen to have the same representation. Here is an overview of their semantics:

NameSemanticsArithmetic operationsBit-wise operations
NatNatural numbersYes (no overflow)No
WordWord in flashNoYes
PositionPosition in virtual storageYes (no overflow)No

Implementations

Source

impl Position

pub fn new(format: &Format, cycle: Nat, page: Nat, word: Nat) -> Position

Create a word position given its coordinates.

The coordinates of a word are:

  • Its word index in its virtual page.
  • Its page index in the storage.
  • The number of times its page was erased.
pub fn get(self) -> Nat

Accesses the underlying position as a natural number.

pub fn index(self, format: &Format) -> StorageIndex

Returns the associated storage index.

pub fn page_begin(self, format: &Format) -> Position

Returns the beginning of the current virtual page.

pub fn next_page(self, format: &Format) -> Position

Returns the beginning of the next virtual page.

pub fn cycle(self, format: &Format) -> Nat

Returns the number of times the current page was erased.

pub fn page(self, format: &Format) -> Nat

Returns the current page index.

pub fn word(self, format: &Format) -> Nat

Returns the current word index in the page.