pub struct Word(/* private fields */);Expand description
Abstract representation of a word in flash.
This type is kept abstract to avoid possible confusion with Nat if they happen to have the
same representation. This is because they have different semantics, Nat represents natural
numbers while Word represents sequences of bits (and thus has no arithmetic).
Implementations