pub struct StoreHandle { /* private fields */ }Expand description
Safe pointer to an entry.
A store handle stays valid at least until the next mutable operation. Store operations taking a handle as argument always verify that the handle is still valid.
Implementations
Sourceimpl StoreHandle
impl StoreHandle
Sourcepub fn get_length<S: Storage>(&self, store: &Store<S>) -> Result<usize, Error>
pub fn get_length<S: Storage>(&self, store: &Store<S>) -> Result<usize, Error>
Returns the value length of the entry.
Errors
Returns INVALID_ARGUMENT if the entry has been deleted or compacted.