pub struct Position(/* private fields */);Expand description
The position of a word in the virtual storage.
With the notations defined in Format, let:
- w denote a word offset in a virtual page, thus between 0 and Q - 1
- p denote a page offset, thus between 0 and N - 1
- c denote the number of times a page was erased, thus between 0 and E
The position of a word is (c * N + p) * Q + w. This position monotonically increases and represents the consumed lifetime of the storage.
This type is kept abstract to avoid possible confusion with Nat and Word if they happen
to have the same representation. Here is an overview of their semantics:
Implementations
Sourceimpl Position
impl Position
Sourcepub fn new(format: &Format, cycle: Nat, page: Nat, word: Nat) -> Position
pub fn new(format: &Format, cycle: Nat, page: Nat, word: Nat) -> Position
Create a word position given its coordinates.
The coordinates of a word are:
- Its word index in its virtual page.
- Its page index in the storage.
- The number of times its page was erased.
Sourcepub fn index(self, format: &Format) -> StorageIndex
pub fn index(self, format: &Format) -> StorageIndex
Returns the associated storage index.
Sourcepub fn page_begin(self, format: &Format) -> Position
pub fn page_begin(self, format: &Format) -> Position
Returns the beginning of the current virtual page.
Sourcepub fn next_page(self, format: &Format) -> Position
pub fn next_page(self, format: &Format) -> Position
Returns the beginning of the next virtual page.